@@ -10,26 +10,31 @@ import time
 
 from datetime import datetime
 
-
 def from_timestamp_property(func_to_decorate):
+    """ A decorator for properties to convert the property value from a 
+    timestamp to a datetime. """
     @functools.wraps(func_to_decorate)
     def wrapper(instance):
+        """ Closure that converts from timestamp to datetime. """
         value = func_to_decorate(instance)
         return datetime.fromtimestamp(value)
     return wrapper
 
 def to_timestamp_property(func_to_decorate):
+    """ A decorator for properties to convert the property value from a 
+    datetime to a timestamp. """
     @functools.wraps(func_to_decorate)
     def wrapper(instance, value):
+        """ Closure that converts from datetime to timestamp. """
         value = time.mktime(value.timetuple())
         func_to_decorate(instance, value)
     return wrapper
 
-
 from .intercom import AuthenticationError
+from .intercom import Intercom
 from .intercom import ResourceNotFound
 from .intercom import ServerError
-from .intercom import Intercom
-from .user import User
-from .message_thread import MessageThread
+
 from .impression import Impression
+from .message_thread import MessageThread
+from .user import User
